@@ -286,9 +286,9 @@ var closeChannel = function (env, channelName, cb) {
     }
 };
 
-var closeInactiveChannels = function (env, schedule, active) {
+var closeInactiveChannels = function (env, schedule, activeSet) {
     Object.keys(env.channels).forEach(channelName => {
-        if (!active.includes(channelName)) {
+        if (!activeSet.has(channelName)) {
             schedule.ordered(channelName, function (next) {
                 closeChannel(env, channelName, next);
             });
@@ -1473,8 +1473,8 @@ module.exports.create = function (conf, _cb) {
                     closeChannel(env, channelName, Util.both(cb, next));
                 });
             },
-            closeInactiveChannels: function (active) {
-                closeInactiveChannels(env, schedule, active);
+            closeInactiveChannels: function (activeSet) {
+                closeInactiveChannels(env, schedule, activeSet);
             },
             // write to a log file
             log: function (channelName, content, cb) {
